[Asterisk-cvs] asterisk/channels chan_iax2.c, 1.270, 1.271 chan_skinny.c, 1.69, 1.70 chan_zap.c, 1.426, 1.427 iax2.h, 1.22, 1.23

russell at lists.digium.com russell at lists.digium.com
Wed Apr 13 18:42:08 CDT 2005


Update of /usr/cvsroot/asterisk/channels
In directory mongoose.digium.com:/tmp/cvs-serv12576/channels

Modified Files:
	chan_iax2.c chan_skinny.c chan_zap.c iax2.h 
Log Message:
add missing newlines, fix misspelling of nonexistent (bug #4027)


Index: chan_skinny.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_skinny.c,v
retrieving revision 1.69
retrieving revision 1.70
diff -u -d -r1.69 -r1.70
--- chan_skinny.c	17 Mar 2005 21:30:19 -0000	1.69
+++ chan_skinny.c	13 Apr 2005 23:33:47 -0000	1.70
@@ -2598,7 +2598,7 @@
 		ast_mutex_destroy(&s->lock);
 		free(s);
 	} else
-		ast_log(LOG_WARNING, "Trying to delete non-existant session %p?\n", s);
+		ast_log(LOG_WARNING, "Trying to delete nonexistent session %p?\n", s);
 	ast_mutex_unlock(&sessionlock);
 }
 

Index: chan_zap.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_zap.c,v
retrieving revision 1.426
retrieving revision 1.427
diff -u -d -r1.426 -r1.427
--- chan_zap.c	6 Apr 2005 19:17:21 -0000	1.426
+++ chan_zap.c	13 Apr 2005 23:33:47 -0000	1.427
@@ -6287,7 +6287,7 @@
 				return 0;
 			}
 		}
-		ast_log(LOG_WARNING, "Channel %d on span %d configured to use non-existant trunk group %d\n", channel, *span, trunkgroup);
+		ast_log(LOG_WARNING, "Channel %d on span %d configured to use nonexistent trunk group %d\n", channel, *span, trunkgroup);
 		*span = -1;
 	} else {
 		if (pris[*span].trunkgroup) {

Index: iax2.h
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/iax2.h,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -d -r1.22 -r1.23
--- iax2.h	17 Mar 2005 21:30:19 -0000	1.22
+++ iax2.h	13 Apr 2005 23:33:47 -0000	1.23
@@ -150,7 +150,7 @@
 
 #define IAX_DPSTATUS_EXISTS			(1 << 0)
 #define IAX_DPSTATUS_CANEXIST		(1 << 1)
-#define IAX_DPSTATUS_NONEXISTANT	(1 << 2)
+#define IAX_DPSTATUS_NONEXISTENT	(1 << 2)
 #define IAX_DPSTATUS_IGNOREPAT		(1 << 14)
 #define IAX_DPSTATUS_MATCHMORE		(1 << 15)
 




More information about the svn-commits mailing list
Index: chan_iax2.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_iax2.c,v
retrieving revision 1.270
retrieving revision 1.271
diff -u -d -r1.270 -r1.271
--- chan_iax2.c	13 Apr 2005 04:47:38 -0000	1.270
+++ chan_iax2.c	13 Apr 2005 23:33:47 -0000	1.271
@@ -573,8 +573,8 @@
 
 /* Extension exists */
 #define CACHE_FLAG_EXISTS		(1 << 0)
-/* Extension is non-existant */
-#define CACHE_FLAG_NONEXISTANT	(1 << 1)
+/* Extension is nonexistent */
+#define CACHE_FLAG_NONEXISTENT	(1 << 1)
 /* Extension can exist */
 #define CACHE_FLAG_CANEXIST		(1 << 2)
 /* Waiting to hear back response */
@@ -1954,8 +1954,8 @@
 		tmp[0] = '\0';
 		if (dp->flags & CACHE_FLAG_EXISTS)
 			strncat(tmp, "EXISTS|", sizeof(tmp) - strlen(tmp) - 1);
-		if (dp->flags & CACHE_FLAG_NONEXISTANT)
-			strncat(tmp, "NONEXISTANT|", sizeof(tmp) - strlen(tmp) - 1);
+		if (dp->flags & CACHE_FLAG_NONEXISTENT)
+			strncat(tmp, "NONEXISTENT|", sizeof(tmp) - strlen(tmp) - 1);
 		if (dp->flags & CACHE_FLAG_CANEXIST)
 			strncat(tmp, "CANEXIST|", sizeof(tmp) - strlen(tmp) - 1);
 		if (dp->flags & CACHE_FLAG_PENDING)
@@ -5181,8 +5181,8 @@
 		status = CACHE_FLAG_EXISTS;
 	else if (ies->dpstatus & IAX_DPSTATUS_CANEXIST)
 		status = CACHE_FLAG_CANEXIST;
-	else if (ies->dpstatus & IAX_DPSTATUS_NONEXISTANT)
-		status = CACHE_FLAG_NONEXISTANT;
+	else if (ies->dpstatus & IAX_DPSTATUS_NONEXISTENT)
+		status = CACHE_FLAG_NONEXISTENT;
 
 	if (ies->dpstatus & IAX_DPSTATUS_IGNOREPAT) {
 		/* Don't really do anything with this */
@@ -5907,7 +5907,7 @@
 	} else if (ast_canmatch_extension(NULL, context, callednum, 1, callerid)) {
 		dpstatus = IAX_DPSTATUS_CANEXIST;
 	} else {
-		dpstatus = IAX_DPSTATUS_NONEXISTANT;
+		dpstatus = IAX_DPSTATUS_NONEXISTENT;
 	}
 	if (ast_ignore_pattern(context, callednum))
 		dpstatus |= IAX_DPSTATUS_IGNOREPAT;
@@ -6292,7 +6292,7 @@
 		ast_mutex_lock(&iaxsl[fr.callno]);
 
 	if (!fr.callno || !iaxs[fr.callno]) {
 		/* A call arrived for a non-existant destination.  Unless it's an "inval"
 		   frame, reply with an inval */
 		if (ntohs(mh->callno) & IAX_FLAG_FULL) {
 			/* We can only raw hangup control frames */
@@ -8833,7 +8833,7 @@
 				ast_verbose(VERBOSE_PREFIX_3 "Executing Dial('%s')\n", req);
 		} else {
 			ast_mutex_unlock(&dpcache_lock);
-			ast_log(LOG_WARNING, "Can't execute non-existant extension '%s[@%s]' in data '%s'\n", exten, context, data);
+			ast_log(LOG_WARNING, "Can't execute nonexistent extension '%s[@%s]' in data '%s'\n", exten, context, data);
 			return -1;
 		}
 	}
@@ -6292,7 +6292,7 @@
 
 	if (!fr.callno || !iaxs[fr.callno]) {
-		/* A call arrived for a non-existant destination.  Unless it's an "inval"
+		/* A call arrived for a nonexistent destination.  Unless it's an "inval"
 		   frame, reply with an inval */
 		if (ntohs(mh->callno) & IAX_FLAG_FULL) {
